# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class TranslationProgress(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TranslationProgress - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'language': 'str',
            'status': 'str',
            'translated_text': 'str',
            'uuid': 'str'
        }

        self.attribute_map = {
            'language': 'language',
            'status': 'status',
            'translated_text': 'translated_text',
            'uuid': 'uuid'
        }

        self._language = None
        self._status = None
        self._translated_text = None
        self._uuid = None

    @property
    def language(self):
        """
        Gets the language of this TranslationProgress.


        :return: The language of this TranslationProgress.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        Sets the language of this TranslationProgress.


        :param language: The language of this TranslationProgress.
        :type: str
        """
        self._language = language

    @property
    def status(self):
        """
        Gets the status of this TranslationProgress.


        :return: The status of this TranslationProgress.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this TranslationProgress.


        :param status: The status of this TranslationProgress.
        :type: str
        """
        self._status = status

    @property
    def translated_text(self):
        """
        Gets the translated_text of this TranslationProgress.


        :return: The translated_text of this TranslationProgress.
        :rtype: str
        """
        return self._translated_text

    @translated_text.setter
    def translated_text(self, translated_text):
        """
        Sets the translated_text of this TranslationProgress.


        :param translated_text: The translated_text of this TranslationProgress.
        :type: str
        """
        self._translated_text = translated_text

    @property
    def uuid(self):
        """
        Gets the uuid of this TranslationProgress.


        :return: The uuid of this TranslationProgress.
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """
        Sets the uuid of this TranslationProgress.


        :param uuid: The uuid of this TranslationProgress.
        :type: str
        """
        self._uuid = uuid

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other): 
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """ 
        Returns true if both objects are not equal
        """
        return not self == other

