# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class SimpleTranslationRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SimpleTranslationRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'client': 'str',
            'created_at': 'datetime',
            'source_language': 'str',
            'target_languages': 'list[str]',
            'text': 'str',
            'uuid': 'str'
        }

        self.attribute_map = {
            'client': 'client',
            'created_at': 'created_at',
            'source_language': 'source_language',
            'target_languages': 'target_languages',
            'text': 'text',
            'uuid': 'uuid'
        }

        self._client = None
        self._created_at = None
        self._source_language = None
        self._target_languages = None
        self._text = None
        self._uuid = None

    @property
    def client(self):
        """
        Gets the client of this SimpleTranslationRequest.


        :return: The client of this SimpleTranslationRequest.
        :rtype: str
        """
        return self._client

    @client.setter
    def client(self, client):
        """
        Sets the client of this SimpleTranslationRequest.


        :param client: The client of this SimpleTranslationRequest.
        :type: str
        """
        self._client = client

    @property
    def created_at(self):
        """
        Gets the created_at of this SimpleTranslationRequest.


        :return: The created_at of this SimpleTranslationRequest.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this SimpleTranslationRequest.


        :param created_at: The created_at of this SimpleTranslationRequest.
        :type: datetime
        """
        self._created_at = created_at

    @property
    def source_language(self):
        """
        Gets the source_language of this SimpleTranslationRequest.


        :return: The source_language of this SimpleTranslationRequest.
        :rtype: str
        """
        return self._source_language

    @source_language.setter
    def source_language(self, source_language):
        """
        Sets the source_language of this SimpleTranslationRequest.


        :param source_language: The source_language of this SimpleTranslationRequest.
        :type: str
        """
        self._source_language = source_language

    @property
    def target_languages(self):
        """
        Gets the target_languages of this SimpleTranslationRequest.


        :return: The target_languages of this SimpleTranslationRequest.
        :rtype: list[str]
        """
        return self._target_languages

    @target_languages.setter
    def target_languages(self, target_languages):
        """
        Sets the target_languages of this SimpleTranslationRequest.


        :param target_languages: The target_languages of this SimpleTranslationRequest.
        :type: list[str]
        """
        self._target_languages = target_languages

    @property
    def text(self):
        """
        Gets the text of this SimpleTranslationRequest.


        :return: The text of this SimpleTranslationRequest.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this SimpleTranslationRequest.


        :param text: The text of this SimpleTranslationRequest.
        :type: str
        """
        self._text = text

    @property
    def uuid(self):
        """
        Gets the uuid of this SimpleTranslationRequest.


        :return: The uuid of this SimpleTranslationRequest.
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """
        Sets the uuid of this SimpleTranslationRequest.


        :param uuid: The uuid of this SimpleTranslationRequest.
        :type: str
        """
        self._uuid = uuid

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other): 
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """ 
        Returns true if both objects are not equal
        """
        return not self == other

